# FIT to GPX Converter

FIT to GPX Converter is a web application that allows users to easily convert Garmin FIT (Flexible and Interoperable Data Transfer) files to GPX (GPS Exchange Format) files. This tool is particularly useful for athletes, outdoor enthusiasts, and anyone who needs to convert their fitness tracking data from FIT to the more widely compatible GPX format.

## Features

- Upload FIT files through a user-friendly web interface
- Automatic conversion of FIT files to GPX format
- View and manage both input (FIT) and output (GPX) files
- Select and delete multiple files
- Responsive design for both desktop and mobile use
- Auto-refresh to show newly converted files


## Preview

![screenshot](./screenshot.png)


## Prerequisites

Before you begin, ensure you have met the following requirements:

- Docker and Docker Compose installed on your system
- Git for cloning the repository

## Installation

To install FIT to GPX Converter, follow these steps:

1. Clone the repository:
   ```
   git clone https://github.com/your-username/fit-to-gpx-converter.git
   cd fit-to-gpx-converter
   ```

2. Build the Docker image:
   ```
   docker-compose build
   ```

3. Start the application:
   ```
   docker-compose up
   ```

The application should now be running and accessible at `http://localhost:5000`.

## Usage

1. Open your web browser and navigate to `http://localhost:5000`.
2. Use the file input to select and upload a .fit file.
3. Click the "Upload and Convert" button.
4. Wait for the conversion process to complete.
5. The converted .gpx file will appear in the "Output Files" list.
6. Click on the file name in the "Output Files" list to download the converted .gpx file.

### Managing Files

- To delete input or output files, select the checkboxes next to the files you wish to remove, then click the "Delete Selected Files" button for the respective list.
- The page automatically refreshes every 30 seconds to show newly converted files.

## Contributing

Contributions to the FIT to GPX Converter are welcome. Please follow these steps to contribute:

1. Fork the repository.
2. Create a new branch: `git checkout -b <branch_name>`.
3. Make your changes and commit them: `git commit -m '<commit_message>'`
4. Push to the original branch: `git push origin <project_name>/<location>`
5. Create the pull request.

Alternatively, see the GitHub documentation on [creating a pull request](https://help.github.com/articles/creating-a-pull-request/).

## License

This project uses the following license: [MIT License](https://opensource.org/licenses/MIT).

## Contact

If you want to contact the maintainer of this project, please email [your-email@example.com](mailto:your-email@example.com).

## Acknowledgements

- [Flask](https://flask.palletsprojects.com/) - The web framework used
- [GPSBabel](https://www.gpsbabel.org/) - Used for file conversion
- [Tailwind CSS](https://tailwindcss.com/) - Used for styling
- [Alpine.js](https://alpinejs.dev/) - Used for interactive elements
